@@ -1,9 +1,8 @@
-# from ..utils import *
-from cloudinary import api, uploader
-
-import click
-from click.utils import make_str
 from click.parser import split_opt
+from click.utils import make_str
+from cloudinary import api, uploader
+from cloudinary.uploader import call_cacheable_api
+from cloudinary.utils import build_upload_params
 
 
 # overrides click.MultiCommand.resolve_command
@@ -33,8 +32,6 @@ def resolve_command(self, ctx, args):
     return cmd_name, cmd, args[1:]
 
 
-from cloudinary.utils import build_upload_params
-from cloudinary.uploader import call_cacheable_api
 def upload(file, **options):
     params = build_upload_params(**options)
     if "resource_type" not in options.keys():
